@@ -1,7 +1,7 @@
 package Net::Stripe::BalanceTransaction;
 use Moose;
-use Moose::Util::TypeConstraints;
-use methods;
+use Moose::Util::TypeConstraints qw(subtype as where message);
+use MooseX::Method::Signatures;
 extends 'Net::Stripe::Resource';
 
 # ABSTRACT: represent a BalanceTransaction object from Stripe
@@ -29,6 +29,9 @@ has 'fee_details'   => (is => 'ro', isa => 'Maybe[ArrayRef]');
 has 'source'        => (is => 'ro', isa => 'Str');
 has 'description'   => (is => 'ro', isa => 'Maybe[Str]');
 
+__PACKAGE__->meta->make_immutable;
+1;
+
 __END__
 
 =pod
@@ -39,7 +42,7 @@ Net::Stripe::BalanceTransaction - represent a BalanceTransaction object from Str
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 AUTHOR
 
