@@ -1,7 +1,7 @@
 package Net::Stripe::Coupon;
 use Moose;
 use Moose::Util::TypeConstraints;
-use methods;
+use MooseX::Method::Signatures;
 extends 'Net::Stripe::Resource';
 
 # ABSTRACT: represent a Coupon object from Stripe
@@ -37,7 +37,7 @@ Net::Stripe::Coupon - represent a Coupon object from Stripe
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 AUTHOR
 
