@@ -1,7 +1,7 @@
 package Net::Stripe::Plan;
 use Moose;
 use Moose::Util::TypeConstraints;
-use methods;
+use MooseX::Method::Signatures;
 extends 'Net::Stripe::Resource';
 
 # ABSTRACT: represent a Plan object from Stripe
@@ -43,7 +43,7 @@ Net::Stripe::Plan - represent a Plan object from Stripe
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 AUTHOR
 
